@@ -188,7 +188,10 @@ def run_ansible(
     client.write_creds(path=AwsCredentialsPath, profile=get_ansible_ssh_profile(client))
 
     if ansible_aws_profile:
-        ansible_client = client.clone(klass=AwsProfile, resource=ansible_aws_profile)
+        ansible_client: AwsProfile = client.clone(
+            klass=AwsProfile, resource=ansible_aws_profile
+        )
+        ansible_client.raise_if_invalid()
     elif ansible_sym_resource:
         ansible_client = client.clone(resource=ansible_sym_resource)
     else:
