@@ -1,3 +1,4 @@
+import os
 import random
 from contextlib import contextmanager
 
@@ -10,6 +11,10 @@ from sym.cli.tests.matchers import succeed
 
 
 def gen_instances():
+    if not os.getenv("SYM_INTEGRATION"):
+        yield "i-xxx"
+        return
+
     ec2 = boto3.client("ec2")
     paginator = ec2.get_paginator("describe_instances")
     for response in paginator.paginate(
@@ -20,9 +25,6 @@ def gen_instances():
                 yield instance["InstanceId"]
 
 
-INSTANCES = list(gen_instances())
-
-
 @pytest.fixture
 def integration_runner(capfdbinary, sandbox, wrapped_cli_runner):
     @contextmanager
@@ -47,5 +49,5 @@ def integration_runner(capfdbinary, sandbox, wrapped_cli_runner):
 def pytest_addoption(parser):
     parser.addoption("--email", default="ci@symops.io")
     parser.addoption("--org", default="sym")
-    parser.addoption("--instance", default=random.choice(INSTANCES))
+    parser.addoption("--instance", default=random.choice(list(gen_instances())))
     parser.addoption("--resource", default="test")
